@@ -218,6 +218,10 @@ class Recognizer():
         def received_message(self, message: ws4py.messaging.TextMessage) -> None:
             """Receive result from websocket"""
             svc_logger.info(f"RECEIVED MESSSGE {message}")
+            if message == "EOS":
+                self.close()
+                return
+
             try:
                 evt = json.loads(str(message))
                 if "id" in evt:
@@ -245,6 +249,11 @@ class Recognizer():
             except Exception as e:
                 svc_logger.error(f"Exception in receive_message: {str(message)}, e: {e}")
                 if self.recognizer._Recognizer__canceled_event.is_set:
+                    evt = {
+                        "session_id": self.recognizer.session_id,
+                        "status": ERROR_IN_SEND_THREAD,
+                        "message": "Error parsing message from STT server",
+                    }
                     evt_res = EventResults(evt)
                     self.recognizer._Recognizer__canceled_event.callback(evt_res)
                 self.recognizer.stop_continuous_recognition_async()
